@@ -47,7 +47,7 @@ s_exp<-function(tau)  exp(2*(tau))
 
 d_exp<-Deriv(s_exp,"tau")
 
-icc0<-function(sa,se,sb) sa/(sa+se)
+icc0<-function(sa,se) sa/(sa+se)
 icc1<-function(sa,se,sb) sa/(sa+sb+se)
 icc2<-function(sa,sab,se,sb) sa/(sa+sab+sb+se)
 icc3<-function(sa,sab,sag,se,sb) (sa+sag)/(sa+sab+sag+se+sb)
